==> gatling-charts-3.7.6-sources.jar: io/gatling/charts/report/AllSessionsReportGenerator.scala <==
/*
 * Copyright 2011-2022 GatlingCorp (https://gatling.io)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.gatling.charts.report

import io.gatling.charts.component.ComponentLibrary
import io.gatling.charts.config.ChartsFiles
import io.gatling.charts.stats.{ IntVsTimePlot, Series }
import io.gatling.charts.util.Colors.Orange
import io.gatling.core.config.GatlingConfiguration

private[charts] class AllSessionsReportGenerator(
    reportsGenerationInputs: ReportsGenerationInputs,
    chartsFiles: ChartsFiles,
    componentLibrary: ComponentLibrary
)(implicit
    configuration: GatlingConfiguration
) extends ReportGenerator {

  def generate(): Unit = {
    import reportsGenerationInputs._

    val series = new Series[IntVsTimePlot]("Active Users", logFileReader.numberOfActiveSessionsPerSecond(None), List(Orange))

    val javascript = componentLibrary.getAllUsersJs(logFileReader.runStart, series)

    new TemplateWriter(chartsFiles.allSessionsFile).writeToFile(javascript)
  }
}

==> gatling-charts-3.8.3-sources.jar: io/gatling/charts/report/AllSessionsReportGenerator.scala <==
/*
 * Copyright 2011-2022 GatlingCorp (https://gatling.io)
 *
 * Licensed under the Apache License, Version 2.0 (the "License");
 * you may not use this file except in compliance with the License.
 * You may obtain a copy of the License at
 *
 *  http://www.apache.org/licenses/LICENSE-2.0
 *
 * Unless required by applicable law or agreed to in writing, software
 * distributed under the License is distributed on an "AS IS" BASIS,
 * WITHOUT WARRANTIES OR CONDITIONS OF ANY KIND, either express or implied.
 * See the License for the specific language governing permissions and
 * limitations under the License.
 */

package io.gatling.charts.report

import io.gatling.charts.component.ComponentLibrary
import io.gatling.charts.config.ChartsFiles
import io.gatling.charts.stats.{ IntVsTimePlot, Series }
import io.gatling.charts.util.Color
import io.gatling.core.config.GatlingConfiguration

private[charts] class AllSessionsReportGenerator(
    reportsGenerationInputs: ReportsGenerationInputs,
    chartsFiles: ChartsFiles,
    componentLibrary: ComponentLibrary
)(implicit
    configuration: GatlingConfiguration
) extends ReportGenerator {

  def generate(): Unit = {
    import reportsGenerationInputs._

    val series = new Series[IntVsTimePlot]("Active Users", logFileData.numberOfActiveSessionsPerSecond(None), List(Color.Users.All))

    val javascript = componentLibrary.getAllUsersJs(logFileData.runInfo.injectStart, series)

    new TemplateWriter(chartsFiles.allSessionsFile).writeToFile(javascript)
  }
}
